//
//  UCPCommunicationCallListProtocol.h
//  UCPFramework
//
//  Created by Christian Weykopf on 27.01.10.
//  Copyright 2010 STARFACE GmbH. All rights reserved.
//

// Keys fo a Call List Entry
extern NSString * const SFCallListEntryIdKey;
extern NSString * const SFCallListEntryCalledNumberKey;
extern NSString * const SFCallListEntryCallerNumberKey;
extern NSString * const SFCallListEntryCallDescriptionKey;
extern NSString * const SFCallListEntryStartTimeKey;
extern NSString * const SFCallListEntryDurationKey;
extern NSString * const SFCallListEntryDirectionKey;
extern NSString * const SFCallListEntryResultKey;
extern NSString * const SFCallListEntryVoicemailIdKey;

// property dircetion
extern NSString * const SFCallListEntryDirectionInbound;
extern NSString * const SFCallListEntryDirectionOutbound;

// property result
extern NSString * const SFCallListEntryResultAnswered;
extern NSString * const SFCallListEntryResultMissed;

// order direction
extern NSString * const SFCallListEntryOrderAscending;
extern NSString * const SFCallListEntryOrderDescending;

/*!
 @category  NSObject(UCPServerCallListRequest)
 @brief     Calls for Call List Requests
 */
@interface NSObject (UCPServerCallListRequest)

/*
 startBefore            date    only retrieve entries that start before date
 startAfter             date    only retrieve entries that start after date
 direction Restriction  string  restrict returned entries by call direction
 result Restriction     string  restrict returned entries by call resolution
 orderProperty          string  specify entry property to order results by 
 orderDirection         string  specify order direction
 countOffset            number  specify offset of first entry returned
 countLimit             number  specify number of entries returned
 */
/*!
 @brief This message can be sent to the UCI server to obtain the call list of the STARFACE user.
 
 */
- (BOOL) getCallListStartBefore: (NSDate *)startBefore
                     startAfter: (NSDate *)startAfter
           directionRestriction: (NSString *)directionRestriction
              resultRestriction: (NSString *)resultRestriction
                  orderProperty: (NSString *)orderProperty
                 orderDirection: (NSString *)orderDirection
                    countOffset: (NSNumber *)countOffset
                     countLimit: (NSNumber *)countLimit
                       delegate: (id)delegate;
- (BOOL) deleteCallListEntry: (NSString *)callId delegate: (id)delegate;

@end

@interface NSObject (UCPServerCallListResponse)

- (void) ucpServerCallList: (id)serverCallList receivedCallList: (NSArray *)callList fault: (NSDictionary *)fault;
- (void) ucpServerCallList: (id)serverCallList receivedDeleteCallListEntry: (NSNumber *)result fault: (NSDictionary *)fault;

@end
