//
//  UCPCommunicationFaxListProtocol.h
//  UCPFramework
//
//  Created by Christian Weykopf on 28.01.10.
//  Copyright 2010 STARFACE GmbH. All rights reserved.
//


// Fax List Entry keys
extern NSString * const SFFaxListEntryIdKey;
extern NSString * const SFFaxListEntryCalledNumberKey;
extern NSString * const SFFaxListEntryCallerNumberKey;
extern NSString * const SFFaxListEntryFallDescriptionKey;
extern NSString * const SFFaxListEntryFolderKey;
extern NSString * const SFFaxListEntryReceptionTimeKey;
extern NSString * const SFFaxListEntrysPartialKey;

// Folder names
extern NSString * const SFFaxListFolderNew;
extern NSString * const SFFaxListFolderOld;
extern NSString * const SFFaxListFolderPrivate;
extern NSString * const SFFaxListFolderSent;

// order direction
extern NSString * const SFFaxListEntryOrderAscending;
extern NSString * const SFFaxListEntryOrderDescending;

@interface NSObject (UCPServerFaxListRequest)

/*
receivedBefore     date    only retrieve entries that have been received before date
receivedAfter      date    only retrieve entries that have been received after date
folderRestriction  string  only retrieve entries in the given folder
orderProperty      string  specify entry property to order results by
orderDirection     string  specify order direction
countOffset        number  specify offset of first entry returned
countLimit         number  specify number of entries returned
*/
- (BOOL)getFaxListReceivedBefore: (NSDate *)receivedBefore
                   receivedAfter: (NSDate *)receivedAfter
               folderRestriction: (NSString *)folderRestriction
                   orderProperty: (NSString *)orderProperty
                  orderDirection: (NSString *)orderDirection
                     countOffset: (NSNumber *)countOffset
                      countLimit: (NSNumber *)countLimit
                        delegate: (id)delegate;
- (BOOL) deleteFaxListEntry: (NSString *)faxId delegate: (id)delegate;
/*
 faxId              string  the ID of the fax list entry to move
 destinationFolder  string  the folder to move the entry into
 */
- (BOOL)moveFaxListEntry: (NSString *)faxId destinationFolder: (NSString *)destinationFolder delegate: (id)delegate;
- (BOOL)getFaxFileUrl: (NSString *)faxId delegate: (id)delegate;

@end

@interface NSObject (UCPServerFaxListResponse)

- (void) ucpServerFaxList: (id)serverFaxList receivedFaxList: (NSArray *)faxList fault: (NSDictionary *)fault;
- (void) ucpServerFaxList: (id)serverFaxList receivedDeleteFaxListEntry: (NSNumber *)result fault: (NSDictionary *)fault;
- (void) ucpServerFaxList: (id)serverFaxList receivedMoveFaxListEntry: (NSNumber *)result fault: (NSDictionary *)fault;
- (void) ucpServerFaxList:  (id)serverFaxList receivedGetFaxFileUrl: (NSString *)faxUrl fault: (NSDictionary *)fault;

@end
