//
//  UCPCommunicationVoicemailListProtocol.h
//  UCPFramework
//
//  Created by Christian Weykopf on 28.01.10.
//  Copyright 2010 STARFACE GmbH. All rights reserved.
//

// keys for Voicemail List Entry
extern NSString * const SFVoicemailListEntryIdKey;
extern NSString * const SFVoicemailListEntryMailboxIdKey;
extern NSString * const SFVoicemailListEntryMailboxNameKey;
extern NSString * const SFVoicemailListEntryFolderKey;
extern NSString * const SFVoicemailListEntryCalledNumberKey;
extern NSString * const SFVoicemailListEntryCallerNumberKey;
extern NSString * const SFVoicemailListEntryCallDescriptionKey;
extern NSString * const SFVoicemailListEntryStartTimeKey;
extern NSString * const SFVoicemailListEntryDurationKey;

// folder names
extern NSString * const SFVoicemailListFolderInbox;
extern NSString * const SFVoicemailListFolderPrivate;
extern NSString * const SFVoicemailListFolderOld;

// order direction
extern NSString * const SFVoicemailListEntryOrderAscending;
extern NSString * const SFVoicemailListEntryOrderDescending;

// keys for mailbox List Entry
extern NSString * const SFMailboxListEntryIdKey;
extern NSString * const SFMailboxListEntryNameKey;

@interface NSObject (UCPServerVoicemailListRequest)

/*
 startBefore         date    only retrieve entries that start before date
 startAfter          date    only retrieve entries that start after date
 mailboxRestriction  string  only retrieve entries in the given mailbox
 folderRestriction   string  only retrieve entries in the given folder
 orderProperty       string  specify entry property to order results by
 orderDirection      string  specify order direction
 countOffset         number  specify offset of first entry returned
 countLimit          number  specify number of entries returned
 */

- (BOOL)getVoicemailListStartBefore: (NSDate *)startBefore
                         startAfter: (NSDate *)startAfter
                 mailboxRestriction: (NSString *)mailboxRestriction
                  folderRestriction: (NSString *)folderRestriction
                      orderProperty: (NSString *)orderProperty
                     orderDirection: (NSString *)orderDirection
                        countOffset: (NSNumber *)countOffset
                         countLimit: (NSNumber *)countLimit
                           delegate: (id)delegate;
- (BOOL)deleteVoicemailListEntry: (NSString *)voicemailId delegate: (id)delegate;
/*
 voicemailId string the ID of the voicemail list entry to move
 destinationFolder string the folder to move the entry into
 */

- (BOOL)moveVoicemailListEntry: (NSString *)voicemailId destinationFolder: (NSString *)destinationFolder delegate: (id)delegate;
- (BOOL)getVoicemailFileUrl: (NSString *)voicemailId delegate: (id)delegate;
/*
 voicemailId        string  the ID of the voicemail to call
 originatingNumber  string  the phone number to be called
 */
- (BOOL)callVoicemailWithNumber: (NSString *)voicemailId originatingNumber: (NSString *)originatingNumber delegate: (id)delegate;
/*
 voicemailId string the ID of the voicemail to call
 phoneId string the id of the phone used to initiate the call with. If not set the primary phone will be used.
 */
- (BOOL)callVoicemailWithPhone: (NSString *)voicemailId phoneId: (NSString *)phoneId delegate: (id)delegate;
- (BOOL)getMailboxesWithDelegate: (id)delegate;
/*
 mailboxId string the ID of the mailbox to call
 originatingNumber string the phone number to be called
 */
- (BOOL)callMailboxWithNumber: (NSString *)mailboxId originatingNumber: (NSString *)originatingNumber delegate: (id)delegate;
/*
 mailboxId string the ID of the mailbox to call
 phoneId string the id of the phone used to initiate the call with. If not set the primary phone will be used
 */
- (BOOL)callMailboxWithPhone: (NSString *)mailboxId phoneId: (NSString *)phoneId delegate: (id)delegate;

@end

@interface NSObject (UCPServerVoicemailListResponse)

- (void)ucpServerVoicemailList: (id)serverVoicemailList receivedVoicemailList: (NSArray *)voicemailList fault: (NSDictionary *)fault;
- (void)ucpServerVoicemailList: (id)serverVoicemailList receivedDeleteVoicemailListEntry: (NSNumber *)result fault: (NSDictionary *)fault;
- (void)ucpServerVoicemailList: (id)serverVoicemailList receivedMoveVoicemailListEntry: (NSNumber *)result fault: (NSDictionary *)fault;
- (void)ucpServerVoicemailList: (id)serverVoicemailList receivedGetVoicemailFileUrl: (NSString *)voicemailUrl fault: (NSDictionary *)fault;
- (void)ucpServerVoicemailList: (id)serverVoicemailList receivedCallVoicemailWithNumber: (NSNumber *)result fault: (NSDictionary *)fault;
- (void)ucpServerVoicemailList: (id)serverVoicemailList receivedCallVoicemailWithPhone: (NSNumber *)result fault: (NSDictionary *)fault;
- (void)ucpServerVoicemailList: (id)serverVoicemailList receivedMailboxes: (NSArray *)mailboxList fault: (NSDictionary *)fault;
- (void)ucpServerVoicemailList: (id)serverVoicemailList receivedCallMailboxWithNumber: (NSNumber *)result fault: (NSDictionary *)fault;
- (void)ucpServerVoicemailList: (id)serverVoicemailList receivedCallMailboxWithPhone: (NSNumber *)result fault: (NSDictionary *)fault;

@end
