//
//  UCPBase.h
//  UCPFramework
//
//  Created by Christian Weykopf on 28.09.09.
//  Copyright 2009 STARFACE GmbH. All rights reserved.
//

#import <Foundation/Foundation.h>
#import "Protocols.h"

extern NSString * const SFPendingRequestTypeKey;
extern NSString * const SFPendingDelegateKey;

@class XMPPConnection;

/*!
 @brief    Base class for all clients.
 @details  This is the base-class for all UCP clients.
 
 Subclasses must override providedService and xmppConnection:didReceiveEvent:params:.
 */
@interface UCPServerService : NSObject  <SFServerProtocol>
{
    id _delegate;
    XMPPConnection *_xmppConnection;
    NSMutableDictionary *_pendingRequests;
}

@property (assign) id delegate;
@property (retain) XMPPConnection *xmppConnection;
@property (retain) NSMutableDictionary *pendingRequests;

- (id) initWithDelegate: (id)delegate xmppConnection: (XMPPConnection *)xmppConnection;

- (NSString *) providedService;

- (BOOL) callServerMethod: (NSString *)methodName withParams: (NSArray *)params pending: (NSDictionary *)pending;

- (void) errorWithErrorCode: (NSString *)errorCode infoDict: (NSDictionary *)infoDict target: (id)target;

- (BOOL) isTargetValid: (id) aTarget andRespondsToSelector: (SEL)aSelector;

@end
