//
//  XMPPConnection.h
//  XMPPStream
//
//  Created by Christian Weykopf on 03.09.09.
//  Copyright 2009 STARFACE GmbH. All rights reserved.
//

/*!
    @header XMPPConnection
    @abstract   connection
    @discussion connection
*/

#import <Foundation/Foundation.h>

@class XMPPStream;
@class XMPPJID;
@class SFClientDispatcher;
@class SFServerDispatcher;

/*!
    @enum       connectionState
    @abstract   connection state
    @discussion schows the connection state
    @constant   notConnected    set if not connected
*/

enum ConnectionState
{
    xmppStreamNotConnected = 0,
    xmppStreamOpen = (1 << 1),          // - (void)xmppStreamDidOpen:(XMPPStream *)sender called
    xmppStreamAuthenticated = (1 << 2), // - (void)xmppStreamDidAuthenticate:(XMPPStream *)sender called
};

enum ConnectionEvent
{
    xmppStreamNoEvent = 0,
    xmppStreamDidOpenEvent = (1 << 1),                      // - (void)xmppStreamDidOpen:(XMPPStream *)sender called
    xmppStreamDidAuthenticateEvent = (1 << 2),              // - (void)xmppStreamDidAuthenticate:(XMPPStream *)sender called
    xmppStreamDidCloseEvent = (1 << 3),                     // - (void)xmppStreamDidClose:(XMPPStream *)sender called
    
    xmppStreamDidReceiveIqElementEvent = (1 << 8),          // - (void)xmppStream:(XMPPStream *)sender didReceiveIQ:(XMPPIQ *)iq called
    xmppStreamDidReceiveMessageElementEvent = (1 << 9),     // - (void)xmppStream:(XMPPStream *)sender didReceiveMessage:(XMPPMessage *)message
    xmppStreamDidReceivePresenceElementEvent = (1 << 10),   // - (void)xmppStream:(XMPPStream *)sender didReceivePresence:(XMPPPresence *)presence
    
    xmppStreamDidNotAuthenticateEvent = (1 << 16),          // - (void)xmppStream:(XMPPStream *)sender didNotAuthenticate:(NSXMLElement *)error called
    xmppStreamDidReceiveErrorEvent = (1 << 17),             // - (void)xmppStream:(XMPPStream *)sender didReceiveError:(id)error called
	
	xmppStreamDidNotResponse = ( 1 << 18)					// - Response timer fired
};

extern NSString * const RpcTypeKey;
extern NSString * const RpcIdKey;
extern NSString * const RpcFromKey;
extern NSString * const RpcToKey;
extern NSString * const RpcResultKey;
extern NSString * const RpcMethodNameKey;
extern NSString * const RpcMethodParamsKey;
extern NSString * const RpcErrorCodeKey;
extern NSString * const RpcErrorTypeKey;
extern NSString * const RpcErrorConditionKey;
extern NSString * const RpcFaultKey;

@interface XMPPConnection : NSObject
{
    @protected
    XMPPStream  *xmppStream;
    XMPPJID     *to;
    XMPPJID     *from;
    id           serverDelegate;
    id           clientDelegate;
	SFClientDispatcher *_clientDispatcher;
	SFServerDispatcher *_serverDispatcher;
    NSUInteger   connectionState;
    NSUInteger   connectionEvent;
}

@property (retain) XMPPStream *xmppStream;
@property (retain) XMPPJID *to;
@property (retain) XMPPJID *from;
@property (assign) id serverDelegate;
@property (assign) id clientDelegate;
@property (assign) NSUInteger connectionState;
@property (assign) NSUInteger connectionEvent;
@property (retain) SFClientDispatcher *clientDispatcher;
@property (retain) SFServerDispatcher *serverDispatcher;

// convinience allocator
+ (XMPPConnection *) connection;
+ (XMPPConnection *) connectionWithDelegate: (id)delegate;
+ (XMPPConnection *) connectionWithDelegate: (id)delegate toJid: (XMPPJID *)to fromJid: (XMPPJID *)from;

- (void) addClient: (id)client forKey: (NSString *)key;
- (void) removeClientForKey: (NSString *)key;

- (void) connectOnPort: (NSUInteger)port secure: (BOOL)secure delegate: (id) delegate;

- (void) connectOnPort: (NSUInteger)port 
                secure: (BOOL)secure 
              username: (NSString *)username 
                domain: (NSString *)domain 
              resource: (NSString *)resource
			  delegate: (id) delegate;
- (void) disconnectWithDelegate: (id) delegate;

- (void)authenticateUser: (NSString *)username withPassword: (NSString *)password resource: (NSString *)resource delegate: (id) delegate;

- (BOOL) callServerMethod: (NSString *)methodName withParams: (NSArray *)params delegate: (id) delegate tag: (NSString *)tag;
- (BOOL) sendResponse: (NSNumber *)result tag: (NSString *)tag;

@end

@interface NSObject (XMPPConnectionDelegate)

- (void) xmppConnection: (XMPPConnection *)sender didReceiveEvent: (enum ConnectionEvent) connectionEvent params: (NSDictionary *)params;

@end